

set -ex



test -f $PREFIX/s390x-conda-linux-gnu/sysroot/lib/libc.so.6
test -f $PREFIX/s390x-conda-linux-gnu/sysroot/sbin/ldconfig
test -f $PREFIX/s390x-conda-linux-gnu/sysroot/usr/lib/crt1.o
test -f $PREFIX/s390x-conda-linux-gnu/sysroot/usr/include/limits.h
test -f $PREFIX/s390x-conda-linux-gnu/sysroot/usr/include/gnu/stubs.h
test -d $PREFIX/s390x-conda-linux-gnu/sysroot/usr/share/locale
test -f $PREFIX/s390x-conda-linux-gnu/sysroot/usr/bin/ldd
test -f $PREFIX/s390x-conda-linux-gnu/sysroot/lib/libc.so.6
exit 0
